This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ray.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
ray.io/v1
RayCluster
RayJob
RayService
ray.io/v1alpha1
RayCluster
RayJob
RayService